@@ -52,7 +52,7 @@ const usage = `usage: fzf [options]
     --hscroll-off=COLS     Number of screen columns to keep to the right of the
                            highlighted substring (default: 10)
     --filepath-word        Make word-wise movements respect path separators
-    --jump-labels=CHARS    Label characters for jump and jump-accept
+    --jump-labels=CHARS    Label characters for jump mode
 
   Layout
     --height=[~]HEIGHT[%]  Display fzf window below the cursor with the given
@@ -75,7 +75,7 @@ const usage = `usage: fzf [options]
     --margin=MARGIN        Screen margin (TRBL | TB,RL | T,RL,B | T,R,B,L)
     --padding=PADDING      Padding inside border (TRBL | TB,RL | T,RL,B | T,R,B,L)
     --info=STYLE           Finder info style
-                           [default|right|hidden|inline[:SEPARATOR]|inline-right]
+                           [default|right|hidden|inline[-right][:PREFIX]]
     --separator=STR        String to form horizontal separator on info line
     --no-separator         Hide info line separator
     --scrollbar[=C1[C2]]   Scrollbar character(s) (each for main and preview window)
@@ -143,7 +143,7 @@ const usage = `usage: fzf [options]
 
 `
 
-const defaultInfoSep = " < "
+const defaultInfoPrefix = " < "
 
 // Case denotes case-sensitivity of search
 type Case int
@@ -217,10 +217,6 @@ const (
 	infoHidden
 )
 
-func (s infoStyle) noExtraLine() bool {
-	return s == infoInline || s == infoInlineRight || s == infoHidden
-}
-
 type labelOpts struct {
 	label  string
 	column int
@@ -327,7 +323,7 @@ type Options struct {
 	ScrollOff    int
 	FileWord     bool
 	InfoStyle    infoStyle
-	InfoSep      string
+	InfoPrefix   string
 	Separator    *string
 	JumpLabels   string
 	Prompt       string
@@ -367,6 +363,10 @@ type Options struct {
 	WalkerRoot   string
 	WalkerSkip   []string
 	Version      bool
+	CPUProfile   string
+	MEMProfile   string
+	BlockProfile string
+	MutexProfile string
 }
 
 func filterNonEmpty(input []string) []string {
@@ -458,14 +458,14 @@ func defaultOptions() *Options {
 
 func help(code int) {
 	os.Stdout.WriteString(usage)
-	os.Exit(code)
+	util.Exit(code)
 }
 
 var errorContext = ""
 
 func errorExit(msg string) {
 	os.Stderr.WriteString(errorContext + msg + "\n")
-	os.Exit(exitError)
+	util.Exit(exitError)
 }
 
 func optString(arg string, prefixes ...string) (bool, string) {
@@ -670,8 +670,8 @@ func parseKeyChordsImpl(str string, message string, exit func(string)) map[tui.E
 			add(tui.CtrlM)
 		case "space":
 			chords[tui.Key(' ')] = key
-		case "bspace", "bs":
-			add(tui.BSpace)
+		case "backspace", "bspace", "bs":
+			add(tui.Backspace)
 		case "ctrl-space":
 			add(tui.CtrlSpace)
 		case "ctrl-delete":
@@ -702,12 +702,16 @@ func parseKeyChordsImpl(str string, message string, exit func(string)) map[tui.E
 			add(tui.One)
 		case "zero":
 			add(tui.Zero)
+		case "jump":
+			add(tui.Jump)
+		case "jump-cancel":
+			add(tui.JumpCancel)
 		case "alt-enter", "alt-return":
 			chords[tui.CtrlAltKey('m')] = key
 		case "alt-space":
 			chords[tui.AltKey(' ')] = key
-		case "alt-bs", "alt-bspace":
-			add(tui.AltBS)
+		case "alt-bs", "alt-bspace", "alt-backspace":
+			add(tui.AltBackspace)
 		case "alt-up":
 			add(tui.AltUp)
 		case "alt-down":
@@ -719,11 +723,11 @@ func parseKeyChordsImpl(str string, message string, exit func(string)) map[tui.E
 		case "tab":
 			add(tui.Tab)
 		case "btab", "shift-tab":
-			add(tui.BTab)
+			add(tui.ShiftTab)
 		case "esc":
-			add(tui.ESC)
-		case "del":
-			add(tui.Del)
+			add(tui.Esc)
+		case "delete", "del":
+			add(tui.Delete)
 		case "home":
 			add(tui.Home)
 		case "end":
@@ -731,27 +735,27 @@ func parseKeyChordsImpl(str string, message string, exit func(string)) map[tui.E
 		case "insert":
 			add(tui.Insert)
 		case "pgup", "page-up":
-			add(tui.PgUp)
+			add(tui.PageUp)
 		case "pgdn", "page-down":
-			add(tui.PgDn)
+			add(tui.PageDown)
 		case "alt-shift-up", "shift-alt-up":
-			add(tui.AltSUp)
+			add(tui.AltShiftUp)
 		case "alt-shift-down", "shift-alt-down":
-			add(tui.AltSDown)
+			add(tui.AltShiftDown)
 		case "alt-shift-left", "shift-alt-left":
-			add(tui.AltSLeft)
+			add(tui.AltShiftLeft)
 		case "alt-shift-right", "shift-alt-right":
-			add(tui.AltSRight)
+			add(tui.AltShiftRight)
 		case "shift-up":
-			add(tui.SUp)
+			add(tui.ShiftUp)
 		case "shift-down":
-			add(tui.SDown)
+			add(tui.ShiftDown)
 		case "shift-left":
-			add(tui.SLeft)
+			add(tui.ShiftLeft)
 		case "shift-right":
-			add(tui.SRight)
+			add(tui.ShiftRight)
 		case "shift-delete":
-			add(tui.SDelete)
+			add(tui.ShiftDelete)
 		case "left-click":
 			add(tui.LeftClick)
 		case "right-click":
@@ -1211,14 +1215,18 @@ func parseActionList(masked string, original string, prevActions []*action, putA
 			appendAction(actToggleSearch)
 		case "toggle-track":
 			appendAction(actToggleTrack)
+		case "toggle-track-current":
+			appendAction(actToggleTrackCurrent)
 		case "toggle-header":
 			appendAction(actToggleHeader)
 		case "show-header":
 			appendAction(actShowHeader)
 		case "hide-header":
 			appendAction(actHideHeader)
-		case "track":
-			appendAction(actTrack)
+		case "track", "track-current":
+			appendAction(actTrackCurrent)
+		case "untrack-current":
+			appendAction(actUntrackCurrent)
 		case "select":
 			appendAction(actSelect)
 		case "select-all":
@@ -1502,17 +1510,24 @@ func parseInfoStyle(str string) (infoStyle, string) {
 	case "right":
 		return infoRight, ""
 	case "inline":
-		return infoInline, defaultInfoSep
+		return infoInline, defaultInfoPrefix
 	case "inline-right":
 		return infoInlineRight, ""
 	case "hidden":
 		return infoHidden, ""
 	default:
-		prefix := "inline:"
-		if strings.HasPrefix(str, prefix) {
-			return infoInline, strings.ReplaceAll(str[len(prefix):], "\n", " ")
+		type infoSpec struct {
+			name  string
+			style infoStyle
 		}
-		errorExit("invalid info style (expected: default|right|hidden|inline[:SEPARATOR]|inline-right)")
+		for _, spec := range []infoSpec{
+			{"inline", infoInline},
+			{"inline-right", infoInlineRight}} {
+			if strings.HasPrefix(str, spec.name+":") {
+				return spec.style, strings.ReplaceAll(str[len(spec.name)+1:], "\n", " ")
+			}
+		}
+		errorExit("invalid info style (expected: default|right|hidden|inline[-right][:PREFIX])")
 	}
 	return infoDefault, ""
 }
@@ -1803,13 +1818,13 @@ func parseOptions(opts *Options, allArgs []string) {
 		case "--no-filepath-word":
 			opts.FileWord = false
 		case "--info":
-			opts.InfoStyle, opts.InfoSep = parseInfoStyle(
+			opts.InfoStyle, opts.InfoPrefix = parseInfoStyle(
 				nextString(allArgs, &i, "info style required"))
 		case "--no-info":
 			opts.InfoStyle = infoHidden
 		case "--inline-info":
 			opts.InfoStyle = infoInline
-			opts.InfoSep = defaultInfoSep
+			opts.InfoPrefix = defaultInfoPrefix
 		case "--no-inline-info":
 			opts.InfoStyle = infoDefault
 		case "--separator":
@@ -1967,6 +1982,14 @@ func parseOptions(opts *Options, allArgs []string) {
 			opts.WalkerSkip = filterNonEmpty(strings.Split(nextString(allArgs, &i, "directory names to ignore required"), ","))
 		case "--version":
 			opts.Version = true
+		case "--profile-cpu":
+			opts.CPUProfile = nextString(allArgs, &i, "file path required: cpu")
+		case "--profile-mem":
+			opts.MEMProfile = nextString(allArgs, &i, "file path required: mem")
+		case "--profile-block":
+			opts.BlockProfile = nextString(allArgs, &i, "file path required: block")
+		case "--profile-mutex":
+			opts.MutexProfile = nextString(allArgs, &i, "file path required: mutex")
 		case "--":
 			// Ignored
 		default:
@@ -2011,7 +2034,7 @@ func parseOptions(opts *Options, allArgs []string) {
 			} else if match, value := optString(arg, "--layout="); match {
 				opts.Layout = parseLayout(value)
 			} else if match, value := optString(arg, "--info="); match {
-				opts.InfoStyle, opts.InfoSep = parseInfoStyle(value)
+				opts.InfoStyle, opts.InfoPrefix = parseInfoStyle(value)
 			} else if match, value := optString(arg, "--separator="); match {
 				opts.Separator = &value
 			} else if match, value := optString(arg, "--scrollbar="); match {
@@ -2236,9 +2259,7 @@ func postProcessOptions(opts *Options) {
 		theme.Spinner = boldify(theme.Spinner)
 	}
 
-	if opts.Scheme != "default" {
-		processScheme(opts)
-	}
+	processScheme(opts)
 }
 
 func expectsArbitraryString(opt string) bool {
@@ -2292,6 +2313,11 @@ func ParseOptions() *Options {
 	errorContext = ""
 	parseOptions(opts, os.Args[1:])
 
+	if err := opts.initProfiling(); err != nil {
+		errorExit("failed to start pprof profiles: " + err.Error())
+	}
+
 	postProcessOptions(opts)
+
 	return opts
 }
